@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1674 2024/11/09 12:59:53 ajacoutot Exp $
+# $OpenBSD: Quirks.pm,v 1.1685 2024/12/22 17:19:43 kirill Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -601,6 +601,8 @@ my $stem_extensions = {
 	'spidermonkey115' => 'spidermonkey128',
 	'blas' => 'lapack',
 	'cblas' => 'lapack',
+	'kio-extras' => 'kf6-kio-extras',
+	'py-rcsparse' => 'py3-rcsparse',
 };
 
 my $obsolete_reason = {};
@@ -770,6 +772,7 @@ setup_obsolete_reason(
 	43 => 'upt-rubygems',
 	3 => 'p5-VCP-autrijus',
 # 7.0
+	3 => qr{^ruby26-},
 	3 => 'mailpile',
 	7 => 'p5-Geo-GDAL',
 	3 => 'gnome-latex',
@@ -978,6 +981,7 @@ setup_obsolete_reason(
 	13 => 'py-scandir',
 	3 => 'd-feet',
 # 7.2
+	3 => qr{^ruby27-},
 	3 => 'gnome-documents',
 	3 => 'lumail',
 	3 => 'kalarmcal',
@@ -1079,6 +1083,7 @@ setup_obsolete_reason(
 	3 => 'ogmrip',
 	3 => 'shrip',
 # 7.4
+	3 => qr{^ruby30-},
 	53 => 'compton',
 	54 => 'depotdownloader',
 	55 => 'residualvm',
@@ -1149,6 +1154,7 @@ setup_obsolete_reason(
 	1 => 'proteus',
 	1 => qr{^tryton},
 # 7.6
+	3 => qr{^ruby31-},
 	5 => 'py3-pyls-black',
 	5 => 'py3-python-language-server',
 	5 => 'py3-python-jsonrpc-server',
@@ -1203,6 +1209,12 @@ setup_obsolete_reason(
 	3 => 'telegram-purple',
 	6 => 'gnome-initial-setup',
 	3 => 'pcmanfm',
+	3 => 'libfm',
+	3 => qr{^nextcloud-(27|28|29)},
+	3 => 'cvs20hg',
+	3 => 'git-cvs',
+	7 => 'py3-uncompyle6',
+	6 => 'py-arsenic',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
